@@ -3,10 +3,15 @@ __license__   = 'GPL v3'
 __copyright__ = '2008, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
-import sys, os, re, time, warnings
-from polyglot.builtins import codepoint_to_chr, hasenv, native_string_type
-from math import floor
+import os
+import re
+import sys
+import time
+import warnings
 from functools import partial
+from math import floor
+
+from polyglot.builtins import codepoint_to_chr, hasenv, native_string_type
 
 if not hasenv('CALIBRE_SHOW_DEPRECATION_WARNINGS'):
     warnings.simplefilter('ignore', DeprecationWarning)
@@ -15,13 +20,25 @@ try:
 except OSError:
     os.chdir(os.path.expanduser('~'))
 
-from calibre.constants import (iswindows, ismacos, islinux, isfrozen,
-        isbsd, preferred_encoding, __appname__, __version__, __author__,
-        plugins, filesystem_encoding, config_dir)
+from calibre.constants import (
+    __appname__,
+    __author__,
+    __version__,
+    config_dir,
+    filesystem_encoding,
+    isbsd,
+    isfrozen,
+    islinux,
+    ismacos,
+    iswindows,
+    plugins,
+    preferred_encoding,
+)
 from calibre.startup import initialize_calibre
+
 initialize_calibre()
-from calibre.utils.icu import safe_chr
 from calibre.prints import prints
+from calibre.utils.icu import safe_chr
 from calibre.utils.resources import get_path as P
 
 if False:
@@ -293,7 +310,7 @@ def is_mobile_ua(ua):
 
 
 def random_user_agent(choose=None, allow_ie=True):
-    from calibre.utils.random_ua import common_user_agents, choose_randomly_by_popularity
+    from calibre.utils.random_ua import choose_randomly_by_popularity, common_user_agents
     ua_list = common_user_agents()
     ua_list = tuple(x for x in ua_list if not is_mobile_ua(x))
     if not allow_ie:
