@@ -10,12 +10,10 @@ import traceback
 
 from calibre import prints
 from calibre.constants import DEBUG
-from calibre.ebooks.metadata.book import (
-    ALL_METADATA_FIELDS, SC_COPYABLE_FIELDS, SC_FIELDS_COPY_NOT_NULL,
-    STANDARD_METADATA_FIELDS, TOP_LEVEL_IDENTIFIERS,
-)
+from calibre.ebooks.metadata.book import ALL_METADATA_FIELDS, SC_COPYABLE_FIELDS, SC_FIELDS_COPY_NOT_NULL, STANDARD_METADATA_FIELDS, TOP_LEVEL_IDENTIFIERS
 from calibre.library.field_metadata import FieldMetadata
-from calibre.utils.icu import lower as icu_lower, sort_key
+from calibre.utils.icu import lower as icu_lower
+from calibre.utils.icu import sort_key
 from calibre.utils.localization import ngettext
 from polyglot.builtins import iteritems, string_or_bytes
 
@@ -150,9 +148,7 @@ class Metadata:
         if field in _data['user_metadata']:
             d = _data['user_metadata'][field]
             val = d['#value#']
-            if d['datatype'] != 'composite':
-                return val
-            if val is None:
+            if val is None and d['datatype'] == 'composite':
                 d['#value#'] = 'RECURSIVE_COMPOSITE FIELD (Metadata) ' + field
                 val = d['#value#'] = self.formatter.safe_format(
                                             d['display']['composite_template'],
@@ -191,8 +187,9 @@ class Metadata:
                 langs = [val]
             _data['languages'] = langs
         elif field in _data['user_metadata']:
-            _data['user_metadata'][field]['#value#'] = val
-            _data['user_metadata'][field]['#extra#'] = extra
+            d = _data['user_metadata'][field]
+            d['#value#'] = val
+            d['#extra#'] = extra
         else:
             # You are allowed to stick arbitrary attributes onto this object as
             # long as they don't conflict with global or user metadata names
@@ -205,11 +202,24 @@ class Metadata:
     def has_key(self, key):
         return key in object.__getattribute__(self, '_data')
 
+    def _evaluate_all_composites(self):
+        custom_fields = object.__getattribute__(self, '_data')['user_metadata']
+        for field in custom_fields:
+            self._evaluate_composite(field)
+
+    def _evaluate_composite(self, field):
+        f = object.__getattribute__(self, '_data')['user_metadata'].get(field, None)
+        if f is not None:
+            if f['datatype'] == 'composite' and f['#value#'] is None:
+                self.get(field)
+
     def deepcopy(self, class_generator=lambda : Metadata(None)):
         ''' Do not use this method unless you know what you are doing, if you
         want to create a simple clone of this object, use :meth:`deepcopy_metadata`
         instead. Class_generator must be a function that returns an instance
         of Metadata or a subclass of it.'''
+        # We don't need to evaluate all the composites here because we
+        # are returning a "real" Metadata instance that has __get_attribute__.
         m = class_generator()
         if not isinstance(m, Metadata):
             return None
@@ -217,6 +227,8 @@ class Metadata:
         return m
 
     def deepcopy_metadata(self):
+        # We don't need to evaluate all the composites here because we
+        # are returning a "real" Metadata instance that has __get_attribute__.
         m = Metadata(None)
         object.__setattr__(m, '_data', copy.deepcopy(object.__getattribute__(self, '_data')))
         return m
@@ -228,6 +240,8 @@ class Metadata:
             return default
 
     def get_extra(self, field, default=None):
+        # Don't need to evaluate all composites because a composite can't have
+        # an extra value
         _data = object.__getattribute__(self, '_data')
         if field in _data['user_metadata']:
             try:
@@ -247,8 +261,7 @@ class Metadata:
         needed is large. Also, we don't want any manipulations of the returned
         dict to show up in the book.
         '''
-        ans = object.__getattribute__(self,
-            '_data')['identifiers']
+        ans = object.__getattribute__(self, '_data')['identifiers']
         if not ans:
             ans = {}
         return copy.deepcopy(ans)
@@ -273,16 +286,14 @@ class Metadata:
         typ, val = self._clean_identifier(typ, val)
         if not typ:
             return
-        identifiers = object.__getattribute__(self,
-            '_data')['identifiers']
+        identifiers = object.__getattribute__(self, '_data')['identifiers']
 
         identifiers.pop(typ, None)
         if val:
             identifiers[typ] = val
 
     def has_identifier(self, typ):
-        identifiers = object.__getattribute__(self,
-            '_data')['identifiers']
+        identifiers = object.__getattribute__(self, '_data')['identifiers']
         return typ in identifiers
 
     # field-oriented interface. Intended to be the same as in LibraryDatabase
@@ -373,6 +384,9 @@ class Metadata:
         return a dict containing all the custom field metadata associated with
         the book.
         '''
+        # Must evaluate all composites because we are returning a dict, not a
+        # Metadata instance
+        self._evaluate_all_composites()
         _data = object.__getattribute__(self, '_data')
         user_metadata = _data['user_metadata']
         if not make_copy:
@@ -388,9 +402,12 @@ class Metadata:
         None. field is the key name, not the label. Return a copy if requested,
         just in case the user wants to change values in the dict.
         '''
-        _data = object.__getattribute__(self, '_data')
-        _data = _data['user_metadata']
+        _data = object.__getattribute__(self, '_data')['user_metadata']
         if field in _data:
+            # Must evaluate the field because it might be a composite. It won't
+            # be evaluated on demand because we are returning its dict, not a
+            # Metadata instance
+            self._evaluate_composite(field)
             if make_copy:
                 return copy.deepcopy(_data[field])
             return _data[field]
