@@ -6,10 +6,26 @@ __copyright__ = '2010, Kovid Goyal <kovid@kovidgoyal.net>'
 __docformat__ = 'restructuredtext en'
 
 import functools
+
 from qt.core import (
-    QAction, QApplication, QDialog, QEvent, QIcon, QLabel, QMenu, QPixmap,
-    QStackedWidget, QStatusBar, QStyle, QStyleOption, QStylePainter, Qt, QTabBar,
-    QTimer, QToolButton, QUrl,
+    QAction,
+    QApplication,
+    QDialog,
+    QEvent,
+    QIcon,
+    QLabel,
+    QMenu,
+    QPixmap,
+    QStackedWidget,
+    QStatusBar,
+    QStyle,
+    QStyleOption,
+    QStylePainter,
+    Qt,
+    QTabBar,
+    QTimer,
+    QToolButton,
+    QUrl,
 )
 
 from calibre.constants import get_appname_for_display, get_version, ismacos
@@ -342,10 +358,15 @@ class VLTabs(QTabBar):  # {{{
     def lock_tab(self):
         gprefs['vl_tabs_closable'] = False
         self.setTabsClosable(False)
+        # Workaround for Qt bug where it doesnt recalculate the tab size after locking
+        for idx in range(self.count()):
+            self.setTabButton(idx, QTabBar.ButtonPosition.RightSide, None)
+            self.setTabButton(idx, QTabBar.ButtonPosition.LeftSide, None)
 
     def unlock_tab(self):
         gprefs['vl_tabs_closable'] = True
         self.setTabsClosable(True)
+        # ensure no button on the All books tab since it is not closeable
         for idx in range(self.count()):
             if not self.tabData(idx):
                 try:
