@@ -8,10 +8,8 @@ __docformat__ = 'restructuredtext en'
 import re
 import time
 from functools import partial
-from qt.core import (
-    QAction, QApplication, QComboBox, QCompleter, QDialog, QEvent, QIcon, QKeyEvent,
-    QKeySequence, QLineEdit, Qt, QTimer, pyqtSignal, pyqtSlot,
-)
+
+from qt.core import QAction, QApplication, QComboBox, QCompleter, QDialog, QEvent, QIcon, QKeyEvent, QKeySequence, QLineEdit, Qt, QTimer, pyqtSignal, pyqtSlot
 
 from calibre.gui2 import QT_HIDDEN_CLEAR_ACTION, config, gprefs, question_dialog
 from calibre.gui2.dialogs.saved_search_editor import SavedSearchEditor
@@ -59,6 +57,12 @@ class SearchLineEdit(QLineEdit):  # {{{
         else:
             menu.addAction(ac)
         menu.addSeparator()
+        ac = menu.addAction(_('Invert current search'))
+        ac.setEnabled(bool(self.text().strip()))
+        ac.setIcon(QIcon.ic('search.png'))
+        ac.triggered.connect(self.invert_search)
+        menu.addAction(ac)
+        menu.addSeparator()
         if self.as_url is not None:
             url = self.as_url(self.text())
             if url:
@@ -66,6 +70,17 @@ class SearchLineEdit(QLineEdit):  # {{{
         menu.addAction(_('&Clear search history')).triggered.connect(self.clear_history)
         menu.exec(ev.globalPos())
 
+    def invert_search(self):
+        q = self.text().strip()
+        if q:
+            if q.startswith('NOT ( ') and q.endswith(' )'):
+                q = q[6:-2]
+            else:
+                q = f'NOT ( {q} )'
+            self.setText(q)
+            ev = QKeyEvent(QEvent.Type.KeyPress, Qt.Key.Key_Enter, Qt.KeyboardModifier.NoModifier)
+            self.keyPressEvent(ev)
+
     def paste_and_search(self):
         self.paste()
         ev = QKeyEvent(QEvent.Type.KeyPress, Qt.Key.Key_Enter, Qt.KeyboardModifier.NoModifier)
@@ -454,6 +469,7 @@ class SavedSearchBoxMixin:  # {{{
         use_hierarchy = 'search' in db.new_api.pref('categories_using_hierarchy', [])
         submenus = {}
         for name in sorted(db.saved_search_names(), key=lambda x: primary_sort_key(x.strip())):
+            display_name = name.replace('&', '&&')
             current_menu = menu
             if use_hierarchy:
                 components = tuple(n.strip() for n in name.split('.'))
@@ -463,14 +479,16 @@ class SavedSearchBoxMixin:  # {{{
                 for i,c in enumerate(hierarchy, start=1):
                     hierarchical_prefix = '.'.join(hierarchy[:i])
                     if hierarchical_prefix not in submenus:
-                        current_menu = current_menu.addMenu(c)
+                        current_menu = current_menu.addMenu(c.replace('&', '&&'))
                         current_menu.setIcon(folder_icon)
                         submenus[hierarchical_prefix] = current_menu
                     else:
                         current_menu = submenus[hierarchical_prefix]
-                ac = add_action(current_menu, name, last, partial(self.search.set_search_string, 'search:"='+name+'"'))
+                ac = add_action(current_menu, display_name, last.replace('&', '&&'),
+                                partial(self.search.set_search_string, 'search:"='+name+'"'))
             else:
-                ac = add_action(current_menu, name, name, partial(self.search.set_search_string, 'search:"='+name+'"'))
+                ac = add_action(current_menu, display_name, display_name,
+                                partial(self.search.set_search_string, 'search:"='+name+'"'))
             if ac.icon().isNull():
                 ac.setIcon(search_icon)
 
