@@ -5,29 +5,43 @@ import os
 import shutil
 import sys
 from itertools import count
+
 from qt.core import (
-    QT_VERSION, QApplication, QByteArray, QEvent, QFontDatabase, QFontInfo, QHBoxLayout,
-    QLocale, QMimeData, QPalette, QSize, Qt, QTimer, QUrl, QWidget, pyqtSignal, sip,
+    QT_VERSION,
+    QApplication,
+    QByteArray,
+    QEvent,
+    QFontDatabase,
+    QFontInfo,
+    QHBoxLayout,
+    QLocale,
+    QMimeData,
+    QPalette,
+    QSize,
+    Qt,
+    QTimer,
+    QUrl,
+    QWidget,
+    pyqtSignal,
+    sip,
 )
 from qt.webengine import (
-    QWebEnginePage, QWebEngineProfile, QWebEngineScript, QWebEngineSettings,
-    QWebEngineUrlRequestJob, QWebEngineUrlSchemeHandler, QWebEngineView,
+    QWebEnginePage,
+    QWebEngineProfile,
+    QWebEngineScript,
+    QWebEngineSettings,
+    QWebEngineUrlRequestJob,
+    QWebEngineUrlSchemeHandler,
+    QWebEngineView,
 )
 
 from calibre import as_unicode, prints
-from calibre.constants import (
-    FAKE_HOST, FAKE_PROTOCOL, __version__, in_develop_mode, is_running_from_develop,
-    ismacos, iswindows,
-)
+from calibre.constants import FAKE_HOST, FAKE_PROTOCOL, __version__, in_develop_mode, is_running_from_develop, ismacos, iswindows
 from calibre.ebooks.metadata.book.base import field_metadata
 from calibre.ebooks.oeb.polish.utils import guess_type
 from calibre.gui2 import choose_images, config, error_dialog, safe_open_url
-from calibre.gui2.viewer import (
-    link_prefix_for_location_links, performance_monitor, url_for_book_in_library,
-)
-from calibre.gui2.viewer.config import (
-    load_viewer_profiles, save_viewer_profile, viewer_config_dir, vprefs,
-)
+from calibre.gui2.viewer import link_prefix_for_location_links, performance_monitor, url_for_book_in_library
+from calibre.gui2.viewer.config import load_viewer_profiles, save_viewer_profile, viewer_config_dir, vprefs
 from calibre.gui2.viewer.tts import TTS
 from calibre.gui2.webengine import RestartingWebEngineView
 from calibre.srv.code import get_translations_data
@@ -36,10 +50,7 @@ from calibre.utils.localization import _, localize_user_manual_link
 from calibre.utils.resources import get_path as P
 from calibre.utils.serialize import json_loads
 from calibre.utils.shared_file import share_open
-from calibre.utils.webengine import (
-    Bridge, create_script, from_js, insert_scripts, secure_webengine, send_reply,
-    setup_profile, to_js,
-)
+from calibre.utils.webengine import Bridge, create_script, from_js, insert_scripts, secure_webengine, send_reply, setup_profile, to_js
 from polyglot.builtins import as_bytes, iteritems
 from polyglot.functools import lru_cache
 
