@@ -7,7 +7,7 @@ __docformat__ = 'restructuredtext en'
 
 import os
 
-from calibre.utils.date import isoformat, DEFAULT_DATE
+from calibre.utils.date import DEFAULT_DATE, isoformat
 from polyglot.builtins import itervalues
 
 
@@ -585,8 +585,7 @@ class SchemaUpgrade:
     def upgrade_version_19(self):
         recipes = self.conn.get('SELECT id,title,script FROM feeds')
         if recipes:
-            from calibre.web.feeds.recipes import custom_recipes, \
-                    custom_recipe_filename
+            from calibre.web.feeds.recipes import custom_recipe_filename, custom_recipes
             bdir = os.path.dirname(custom_recipes.file_path)
             for id_, title, script in recipes:
                 existing = frozenset(map(int, custom_recipes))
