@@ -11,9 +11,15 @@ import sys
 
 from calibre import force_unicode
 from calibre.constants import (
-    FAKE_HOST, FAKE_PROTOCOL, SPECIAL_TITLE_FOR_WEBENGINE_COMMS, __appname__,
-    __version__, builtin_colors_dark, builtin_colors_light, builtin_decorations,
-    dark_link_color
+    FAKE_HOST,
+    FAKE_PROTOCOL,
+    SPECIAL_TITLE_FOR_WEBENGINE_COMMS,
+    __appname__,
+    __version__,
+    builtin_colors_dark,
+    builtin_colors_light,
+    builtin_decorations,
+    dark_link_color,
 )
 from calibre.ptempfile import TemporaryDirectory
 from calibre.utils.filenames import atomic_rename
@@ -60,9 +66,7 @@ def compiler():
 
     from calibre import walk
     from calibre.gui2 import must_use_qt
-    from calibre.utils.webengine import (
-        secure_webengine, setup_default_profile, setup_profile
-    )
+    from calibre.utils.webengine import secure_webengine, setup_default_profile, setup_profile
     must_use_qt()
     setup_default_profile()
 
@@ -346,20 +350,15 @@ def atomic_write(base, name, content):
 
 
 def run_rapydscript_tests():
-    from qt.core import QApplication, QByteArray, QEventLoop, QUrl
-    from qt.webengine import (
-        QWebEnginePage, QWebEngineProfile, QWebEngineScript, QWebEngineUrlRequestJob,
-        QWebEngineUrlSchemeHandler
-    )
     from urllib.parse import parse_qs
 
+    from qt.core import QApplication, QByteArray, QEventLoop, QUrl
+    from qt.webengine import QWebEnginePage, QWebEngineProfile, QWebEngineScript, QWebEngineUrlRequestJob, QWebEngineUrlSchemeHandler
+
     from calibre.constants import FAKE_HOST, FAKE_PROTOCOL
     from calibre.gui2 import must_use_qt
     from calibre.gui2.viewer.web_view import send_reply
-    from calibre.utils.webengine import (
-        create_script, insert_scripts, secure_webengine, setup_default_profile,
-        setup_fake_protocol, setup_profile
-    )
+    from calibre.utils.webengine import create_script, insert_scripts, secure_webengine, setup_default_profile, setup_fake_protocol, setup_profile
     must_use_qt()
     setup_fake_protocol()
     setup_default_profile()
