@@ -17,7 +17,7 @@ from calibre import sanitize_file_name
 from calibre.constants import filesystem_encoding
 from calibre.ebooks.chardet import detect
 from calibre.ptempfile import SpooledTemporaryFile
-from polyglot.builtins import string_or_bytes, as_bytes
+from polyglot.builtins import as_bytes, string_or_bytes
 
 try:
     import zlib  # We may need its compression method
